package com.huimv.eartag2.manage.controller;

import com.huimv.eartag2.common.utils.Result;
import com.huimv.eartag2.manage.service.ICacheService;
import com.huimv.eartag2.manage.service.IDeviceService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.text.ParseException;

/**
 * @Project : huimv.shiwan
 * @Package : com.huimv.biosafety.uface.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@RestController
@RequestMapping(value = "/device")
@Slf4j
public class DeviceController {
    @Autowired
    private ICacheService cacheService;
    @Autowired
    private RabbitTemplate rabbitTemplate;
    @Autowired
    private IDeviceService deviceService;

    /**
     * @Method      : getNowAllStatus
     * @Description : 读取最新设备和耳标总状态
     * @Params      : []
     * @Return      : void
     * 
     * @Author      : ZhuoNing
     * @Date        : 2022/3/5       
     * @Time        : 17:03
     */
    @RequestMapping(value = "/getNowAllStatus",method = RequestMethod.GET)
    public Result getNowAllStatus(@RequestParam(value = "farmId",required = true) String farmId) throws ParseException {
        log.info("<getNowAllStatus>输入参数 farmId>>"+farmId);
        //
        return deviceService.getNowAllStatus(farmId);
    }

    /**
     * @Method      : listManyDaysAllStatus
     * @Description : 显示N天的总状态记录
     * @Params      : [farmId, days]
     * @Return      : com.huimv.eartag2.common.utils.Result
     *
     * @Author      : ZhuoNing
     * @Date        : 2022/3/6
     * @Time        : 22:18
     */
    @RequestMapping(value = "/listManyDaysAllStatus",method = RequestMethod.GET)
    public Result listManyDaysAllStatus(@RequestParam(value = "farmId",required = true) String farmId,@RequestParam(value = "days",required = true) Integer days) throws ParseException {
        log.info("<listManyDaysAllStatus>输入参数 farmId>>"+farmId);
        log.info("<listManyDaysAllStatus>输入参数 days>>"+days);
        if(days == null){
            //默认7天数据
            days = 7;
        }
        //
        return deviceService.listManyDaysAllStatus(farmId,days);
    }

    /**
     * @Method      : listOnlineDevice
     * @Description : 显示当天在线设备记录
     * @Params      : [farmId]
     * @Return      : com.huimv.eartag2.common.utils.Result
     *
     * @Author      : ZhuoNing
     * @Date        : 2022/3/7
     * @Time        : 11:09
     */
    @RequestMapping(value = "/listOnlineDevice",method = RequestMethod.GET)
    public Result listOnlineDevice(@RequestParam(value = "farmId",required = true) String farmId) throws ParseException {
        log.info("<listOnlineDevice>输入参数 farmId>>"+farmId);
        //
        return deviceService.listOnlineDevice(farmId);
    }

    /**
     * @Method      : listOnlineDeviceByPager
     * @Description : 分页显示N天在线记录
     * @Params      : [farmId, deviceCode, alias, addDate, pageNo, pageSize]
     * @Return      : com.huimv.eartag2.common.utils.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2022/3/7       
     * @Time        : 20:22
     */
    @RequestMapping(value = "/listOnlineDeviceByPager",method = RequestMethod.GET)
    public Result listOnlineDeviceByPager(@RequestParam(value = "farmId",required = true) String farmId,
                                    @RequestParam(value = "deviceCode",required = false) String deviceCode,
                                    @RequestParam(value = "alias",required = false) String alias,
                                    @RequestParam(value = "addDate",required = false) String addDate,
                                    @RequestParam(value = "pageNo",required = true) Integer pageNo,
                                    @RequestParam(value = "pageSize",required = true) Integer pageSize) throws ParseException {
        log.info("<listOnlineDevice>输入参数 farmId>>"+farmId);
        log.info("<listOnlineDevice>输入参数 deviceCode>>"+deviceCode);
        log.info("<listOnlineDevice>输入参数 alias>>"+alias);
        log.info("<listOnlineDevice>输入参数 addDate>>"+addDate);
        log.info("<listOnlineDevice>输入参数 pageNo>>"+pageNo);
        log.info("<listOnlineDevice>输入参数 pageSize>>"+pageSize);
        //
        return deviceService.listOnlineDevice(farmId,deviceCode,alias,addDate,pageNo,pageSize);
    }

    /**
     * @Method      : getDeviceRegisterByDeviceCode
     * @Description : 通过设备编码查询设备注册信息
     * @Params      : [deviceCode]
     * @Return      : com.huimv.eartag2.common.utils.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2022/3/7       
     * @Time        : 14:01
     */
    @RequestMapping(value = "/getDeviceRegisterByDeviceCode",method = RequestMethod.GET)
    public Result getDeviceRegisterByDeviceCode(@RequestParam(value = "deviceCode",required = true) String deviceCode){
        log.info("<getDeviceRegisterByDeviceCode>输入参数 deviceCode>>"+deviceCode);
        //
        return deviceService.getDeviceRegisterByDeviceCode(deviceCode);
    }

    /**
     * @Method      : listManyDaysOnlineByDeviceCode
     * @Description : 查询单个设备N天在线记录-showMode:1（记录） ,2（图表）
     * @Params      : [deviceCode]
     * @Return      : com.huimv.eartag2.common.utils.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2022/3/7       
     * @Time        : 14:07
     */
    @RequestMapping(value = "/listDeviceOnlineCountByDeviceCode",method = RequestMethod.GET)
    public Result listDeviceOnlineCountByDeviceCode(@RequestParam(value = "deviceCode",required = true) String deviceCode,@RequestParam(value = "pastDays",required = true) Integer pastDays,@RequestParam(value = "showMode",required = true) Integer showMode) throws ParseException {
        log.info("<listManyDaysOnlineByDeviceCode>输入参数 deviceCode>>"+deviceCode);
        log.info("<listManyDaysOnlineByDeviceCode>输入参数 pastDays>>"+pastDays);
        log.info("<listManyDaysOnlineByDeviceCode>输入参数 showMode>>"+showMode);
        if(pastDays == null){
            pastDays = 7;
        }
        if(showMode == null){
            showMode = 1;
        }
        //查询单个设备N天在线记录
        return deviceService.listDeviceOnlineCountByDeviceCode(deviceCode,pastDays,showMode);
    }

    /**
     * @Method      : listDeviceOnlineStatusByDeviceCode
     * @Description : 显示设备在线状态
     * @Params      : [deviceCode, pastDays]
     * @Return      : com.huimv.eartag2.common.utils.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2022/3/7       
     * @Time        : 15:44
     */
    @RequestMapping(value = "/listDeviceOnlineStatusByDeviceCode",method = RequestMethod.GET)
    public Result listDeviceOnlineStatusByDeviceCode(@RequestParam(value = "deviceCode",required = true) String deviceCode,@RequestParam(value = "pastDays",required = true) Integer pastDays) throws ParseException {
        log.info("<listManyDaysOnlineByDeviceCode>输入参数 deviceCode>>"+deviceCode);
        log.info("<listManyDaysOnlineByDeviceCode>输入参数 pastDays>>"+pastDays);
        if(pastDays == null){
            pastDays = 7;
        }
        //查询单个设备N天在线记录
        return deviceService.listDeviceOnlineStatusByDeviceCode(deviceCode,pastDays);
    }

    /**
     * @Method      : listEartagOnlineCountByDeviceCode
     * @Description : 显示设备关联耳标统计
     * @Params      : [deviceCode]
     * @Return      : com.huimv.eartag2.common.utils.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2022/3/7       
     * @Time        : 18:11
     */
    @RequestMapping(value = "/listDeviceEartagOnlineCountByDeviceCode",method = RequestMethod.GET)
    public Result listDeviceEartagOnlineCountByDeviceCode(@RequestParam(value = "deviceCode",required = true) String deviceCode) throws ParseException {
        log.info("<listEartagOnlineCountByDeviceCode>输入参数 deviceCode>>"+deviceCode);
        //查询设备关联的在线耳标统计
        return deviceService.listDeviceEartagOnlineCountByDeviceCode(deviceCode);
    }

}
